@@ -115,7 +115,8 @@ namespace Banshee
 	public enum SourceType : uint {
 		Library = 1,
 		Playlist = 2,
-		Ipod = 3
+		Ipod = 3,
+		AudioCd
 	}
 
 	public abstract class Source
@@ -165,7 +166,10 @@ namespace Banshee
 			}
 		}
 		
-		public abstract void UpdateName(string oldName, string newName);
+		public virtual void UpdateName(string oldName, string newName)
+		{
+		
+		}
 		
 		public virtual bool Eject()
 		{
@@ -180,11 +184,6 @@ namespace Banshee
 		
 		}
 		
-		public override void UpdateName(string oldName, string newName)
-		{
-			
-		}
-		
 		public override int Count
 		{
 			get {
@@ -265,6 +264,38 @@ namespace Banshee
 			return true;
 		}
 	}
+	
+	public class AudioCdSource : Source
+	{
+		private AudioDisk disk;
+		
+		public AudioCdSource(AudioDisk disk) : base(disk.DriveName, 
+			SourceType.AudioCd)
+		{
+			this.disk = disk;
+			canEject = true;
+		}
+		
+		public override int Count
+		{
+			get {
+				return disk.TrackCount;
+			}
+		}
+		
+		public AudioDisk Disk
+		{
+			get {
+				return disk;
+			}
+		}
+		
+		public override bool Eject()
+		{
+			disk.Eject();
+			return true;
+		}
+	}
 
 	public class Playlist 
 	{
