@@ -33,6 +33,7 @@ using System.Collections;
 using Gtk;
 using Gdk;
 using Glade;
+using Mono.Posix;
 
 using Sql;
 
@@ -79,14 +80,15 @@ namespace Banshee
 			}
 		}
 		
-		private IpodCore ipodCore = IpodCore.Instance;
-		private AudioCdCore audioCdCore = AudioCdCore.Instance;
+		private IpodCore ipodCore = Core.Instance.IpodCore;
+		private AudioCdCore audioCdCore = Core.Instance.AudioCdCore;
 		
 		private long plLoaderMax, plLoaderCount;
 		private bool startupLoadReady = false;
 		private bool tickFromEngine = false;
 		private uint setPositionTimeoutId;
 		private bool updateEnginePosition = true;
+		private int clickX, clickY;
 
 		private int ipodDiskUsageTextViewState;
 
@@ -116,12 +118,15 @@ namespace Banshee
 
         public PlayerUI() 
         {
+			Catalog.Init("banshee", ConfigureDefines.LOCALE_DIR);
+		
 			gxml = new Glade.XML(null, "player.glade", "WindowPlayer", null);
 			gxml.Autoconnect(this);
 
 			ResizeMoveWindow();
 			BuildWindow();   
 			InstallTrayIcon();
+			WindowPlayer.Show();
 			
 			Core.Instance.Player.Iterate += OnPlayerTick;
 			Core.Instance.Player.EndOfStream += OnPlayerEos;		
@@ -179,7 +184,7 @@ namespace Banshee
       	private void BuildWindow()
       	{
 			// Icons and Pixbufs
-      		WindowPlayer.Icon = Gdk.Pixbuf.LoadFromResource("sonance-icon.png");
+      		WindowPlayer.Icon = Gdk.Pixbuf.LoadFromResource("banshee-icon.png");
 			
 			ImagePrevious.SetFromStock("media-prev", IconSize.LargeToolbar);
 			ImageNext.SetFromStock("media-next", IconSize.LargeToolbar);
@@ -216,7 +221,7 @@ namespace Banshee
 			Label sourceViewLoading = new Label();
 			sourceViewLoading.Yalign = 0.15f;
 			sourceViewLoading.Xalign = 0.5f;
-			sourceViewLoading.Markup = "<big><i>Loading...</i></big>";
+			sourceViewLoading.Markup = Catalog.GetString("<big><i>Loading...</i></big>");
 			sourceViewLoadingVP = new Viewport();
 			sourceViewLoadingVP.ShadowType = ShadowType.None;
 			sourceViewLoadingVP.Add(sourceViewLoading);
@@ -246,6 +251,7 @@ namespace Banshee
 			playlistView.Show();
 			playlistModel.Updated += OnPlaylistUpdated;
 			playlistView.ButtonPressEvent += OnPlaylistViewButtonPressEvent;
+			playlistView.MotionNotifyEvent += OnPlaylistViewMotionNotifyEvent;
 			playlistView.DragDataReceived += OnPlaylistViewDragDataReceived;
 			playlistView.DragDataGet += OnPlaylistViewDragDataGet;
 			playlistView.DragMotion += OnPlaylistViewDragMotion;
@@ -306,17 +312,17 @@ namespace Banshee
 				false, false, 0);
 				
 			toolTips = new Tooltips();
-			toolTips.SetTip(gxml["ButtonNewPlaylist"], "Create New Playlist", "Create New Playlist");
-			toolTips.SetTip(gxml["ToggleButtonShuffle"], "Toggle Shuffle Playback Mode", "Toggle Shuffle Playback Mode");
-			toolTips.SetTip(gxml["ToggleButtonRepeat"], "Toggle Repeat Playback Mode", "Toggle Repeat Playback Mode");
-			toolTips.SetTip(gxml["ButtonTrackProperties"], "View Selected Song Information", "View Selected Song Information");
-			toolTips.SetTip(gxml["ButtonBurn"], "Burn Selection to CD", "Burn Selection to CD");
-			toolTips.SetTip(gxml["ButtonPrevious"], "Play Previous Song", "Play Previous Song");
-			toolTips.SetTip(gxml["ButtonPlayPause"], "Play/Pause Current Song", "Play/Pause Current Song");
-			toolTips.SetTip(gxml["ButtonNext"], "Play Next Song", "Play Next Song");
-			toolTips.SetTip(gxml["ScaleTime"], "Current Position in Song", "Current Position in Song");
-			toolTips.SetTip(volumeButton, "Adjust Volume", "Adjust Volume");
-			toolTips.SetTip(ipodDiskUsageBar, "iPod Disk Usage", "iPod Disk Usage");
+			SetTip(gxml["ButtonNewPlaylist"], Catalog.GetString("Create New Playlist"));
+			SetTip(gxml["ToggleButtonShuffle"], Catalog.GetString("Toggle Shuffle Playback Mode"));
+			SetTip(gxml["ToggleButtonRepeat"], Catalog.GetString("Toggle Repeat Playback Mode"));
+			SetTip(gxml["ButtonTrackProperties"], Catalog.GetString("View Selected Song Information"));
+			SetTip(gxml["ButtonBurn"], Catalog.GetString("Burn Selection to CD"));
+			SetTip(gxml["ButtonPrevious"], Catalog.GetString("Play Previous Song"));
+			SetTip(gxml["ButtonPlayPause"], Catalog.GetString("Play/Pause Current Song"));
+			SetTip(gxml["ButtonNext"], Catalog.GetString("Play Next Song"));
+			SetTip(gxml["ScaleTime"], Catalog.GetString("Current Position in Song"));
+			SetTip(volumeButton, Catalog.GetString("Adjust Volume"));
+			SetTip(ipodDiskUsageBar, Catalog.GetString("iPod Disk Usage"));
 			
 			playlistMenuMap = new Hashtable();
 			
@@ -324,12 +330,17 @@ namespace Banshee
 				new BansheeCore(Window), "/org/gnome/Banshee/Core");
       	}
       	
+      	private void SetTip(Widget widget, string tip)
+      	{
+      		toolTips.SetTip(widget, tip, tip);
+      	}
+      	
       	private void InstallTrayIcon()
       	{
       		try {
 				trayIcon = new NotificationAreaIcon();
 				trayIcon.ClickEvent += new EventHandler(OnTrayClick);
-				trayIcon.ScrollEvent += new ScrollEventHandler(OnTrayScroll);
+				//trayIcon.ScrollEvent += new ScrollEventHandler(OnTrayScroll);
 				
 				trayIcon.PlayItem.Activated += 
 					new EventHandler(OnButtonPlayPauseClicked);
@@ -345,7 +356,8 @@ namespace Banshee
 					new EventHandler(OnMenuQuitActivate);
 			} catch(Exception) {
 				trayIcon = null;
-				DebugLog.Add("egg-tray could not be installed [no libsonance]");
+				DebugLog.Add(Catalog.GetString(
+					"Notification Area Icon could not be installed"));
 			}
 		}
 	
@@ -385,14 +397,15 @@ namespace Banshee
 			
 			HigMessageDialog md = new HigMessageDialog(WindowPlayer, 
 				DialogFlags.DestroyWithParent, MessageType.Question,
-				"Import Music",
-				"Your music library is empty. You may import new music into " +
+				Catalog.GetString("Import Music"),
+				Catalog.GetString("Your music library is empty. You may import new music into " +
 				"your library now, or choose to do so later.\n\nAutomatic import " +
 				"or importing a large folder may take a long time, so please " +
-				"be patient.",
-				"Import Folder");
+				"be patient."),
+				Catalog.GetString("Import Folder"));
 				
-			md.AddButton("Automatic Import", Gtk.ResponseType.Apply, true);
+			md.AddButton(Catalog.GetString("Automatic Import"), 
+				Gtk.ResponseType.Apply, true);
 			
 			switch(md.Run()) {
 				case (int)ResponseType.Ok:
@@ -753,7 +766,7 @@ namespace Banshee
 		private void ImportWithFileSelector()
 		{
 			FileChooserDialog chooser = new FileChooserDialog(
-				"Import Folder to Library",
+				Catalog.GetString("Import Folder to Library"),
 				null,
 				FileChooserAction.SelectFolder,
 				"gnome-vfs"
@@ -782,7 +795,7 @@ namespace Banshee
 		private void OnMenuImportFilesActivate(object o, EventArgs args)
 		{
 			FileChooserDialog chooser = new FileChooserDialog(
-				"Import Files to Library",
+				Catalog.GetString("Import Files to Library"),
 				null,
 				FileChooserAction.Open,
 				"gnome-vfs"
@@ -848,7 +861,9 @@ namespace Banshee
 				
 				Core.ThreadEnter();
 				(gxml["ViewNameLabel"] as Label).Markup = 
-					"<b>" + Core.Instance.UserFirstName + " Music Library</b>";
+					String.Format(Catalog.GetString("<b>{0} Music Library</b>"),
+						Core.Instance.UserFirstName);
+				
 				Core.ThreadLeave();
 			} else if(source.Type == SourceType.Ipod) {
 				playlistModel.Clear();
@@ -873,7 +888,7 @@ namespace Banshee
 				
 				ipodDiskUsageBar.Text = usedstr + " of " + totalstr;
 				string tooltip = ipodDiskUsageBar.Text + " (" + availstr + 
-					" Remaining)";
+					" " + Catalog.GetString("Remaining") + ")";
 				toolTips.SetTip(ipodDiskUsageBar, tooltip, tooltip);
 				
 				Core.ThreadEnter();
@@ -964,20 +979,20 @@ namespace Banshee
 				Gdk.Threads.Enter();
 			
 			if(count == 0 && playlistModel.Source == null) {
-				LabelStatusBar.Text = "Banshee Music Player";
+				LabelStatusBar.Text = Catalog.GetString("Banshee Music Player");
 			} else if(count == 0) {
 				switch(playlistModel.Source.Type) {
 					case SourceType.Library:
-						LabelStatusBar.Text = "Your Library is Empty - Consider Importing Music";
+						LabelStatusBar.Text = Catalog.GetString("Your Library is Empty - Consider Importing Music");
 						break;
 					case SourceType.Playlist:
-						LabelStatusBar.Text = "This Playlist is Empty - Consider Adding Music";
+						LabelStatusBar.Text = Catalog.GetString("This Playlist is Empty - Consider Adding Music");
 						break;
 				}
 			} else
 				LabelStatusBar.Text = String.Format(
-					"{0} Items, {1} Total Play Time",
-					count, timeDisp);
+					Catalog.GetString("{0} Items, {1} Total Play Time") + " [{2}]",
+					count, timeDisp, playlistModel.TotalDuration);
 				
 			if(!Core.Instance.MainThread.Equals(Thread.CurrentThread))
 				Gdk.Threads.Leave();
@@ -994,14 +1009,17 @@ namespace Banshee
 		{
 			int selCount = playlistView.Selection.CountSelectedRows();
 		
+			if(selCount <= 0)
+				return;
+		
 			if(playlistModel.Source.Type == SourceType.Library) {
 				HigMessageDialog md = new HigMessageDialog(WindowPlayer, 
 					DialogFlags.DestroyWithParent, MessageType.Warning,
 					ButtonsType.YesNo,
-					"Remove Selected Songs from Library",
-					String.Format(
-					"Are you sure you want to remove the selected <b>({0})</b> " +
-					"song{1} from your library?", selCount, selCount == 1 ? "" : "s"));
+					Catalog.GetString("Remove Selected Songs from Library"),
+					String.Format(Catalog.GetString(
+					"Are you sure you want to remove the selected <b>({0})</b> song(s) from your library?"), selCount)
+				);
 				
 				if(md.Run() != (int)ResponseType.Yes) {
 					md.Destroy();
@@ -1152,8 +1170,10 @@ namespace Banshee
 				sourceView.HighlightedSource.Type == SourceType.Library)
 				return;
 				
-			InputDialog input = new InputDialog("Rename Playlist",
-				"Enter new playlist name", "playlist-icon-large.png", 
+			InputDialog input = new InputDialog(
+				Catalog.GetString("Rename Playlist"),
+				Catalog.GetString("Enter new playlist name"), 
+				"playlist-icon-large.png", 
 				sourceView.HighlightedSource.Name);
 			string newName = input.Execute();
 			if(newName != null)
@@ -1199,6 +1219,7 @@ namespace Banshee
 					playlistModel.LoadFromIpodSource(source as IpodSource);
 				else
 					playlistModel.LoadFromLibrary();
+				
 				return;
 			}
 			
@@ -1281,6 +1302,8 @@ namespace Banshee
 		
 			if(path == null)
 				return;
+			clickX = (int)args.Event.X;
+			clickY = (int)args.Event.Y;
 		
 			switch(args.Event.Type) {
 				case EventType.TwoButtonPress:
@@ -1302,6 +1325,21 @@ namespace Banshee
 			}
 		}
 
+		[GLib.ConnectBefore]
+		private void OnPlaylistViewMotionNotifyEvent(object o, 
+			MotionNotifyEventArgs args)
+		{
+			if((args.Event.State & ModifierType.Button1Mask) == 0)
+				return;
+			if(!Gtk.Drag.CheckThreshold(playlistView, clickX, clickY,
+						    (int)args.Event.X, (int)args.Event.Y))
+				return;
+		
+			Gtk.Drag.Begin(playlistView, new TargetList (playlistViewSourceEntries),
+				       Gdk.DragAction.Move, 1, args.Event);
+			args.RetVal = true;
+		}
+
 		private bool PlaylistMenuPopupTimeout(uint time)
 		{
 			if(gxmlPlaylistMenu == null) {
@@ -1317,7 +1355,7 @@ namespace Banshee
 				Menu plMenu = new Menu();
 				playlistMenuMap.Clear();
 				
-				ImageMenuItem newPlItem = new ImageMenuItem("New Playlist");
+				ImageMenuItem newPlItem = new ImageMenuItem(Catalog.GetString("New Playlist"));
 				newPlItem.Image = new Gtk.Image("gtk-new", IconSize.Menu);
 				newPlItem.Activated += OnNewPlaylistFromSelectionActivated;
 				plMenu.Append(newPlItem);
@@ -1341,7 +1379,7 @@ namespace Banshee
 				
 				Menu ratingMenu = new Menu();
 				
-				MenuItem clearItem = new MenuItem("Clear");
+				MenuItem clearItem = new MenuItem(Catalog.GetString("Clear"));
 				clearItem.Name = "0";
 				clearItem.Activated += OnItemRatingActivated;
 				
@@ -1416,11 +1454,11 @@ namespace Banshee
 		private void OnPlaylistViewDragMotion(object o, DragMotionArgs args)
 		{
 			TreePath path;
+			TreeViewDropPosition pos;
 
-			if(!playlistView.GetPathAtPos(args.X, args.Y, out path))
+			if(!playlistView.GetDestRowAtPos(args.X, args.Y, out path, out pos))
 				return;
-				
-			playlistView.SetDragDestRow(path, Gtk.TreeViewDropPosition.Before);
+			playlistView.SetDragDestRow(path, (TreeViewDropPosition)((int)pos & 0x1));
 		}
 		
 		private void OnPlaylistViewDragDataReceived(object o, 
@@ -1476,11 +1514,16 @@ namespace Banshee
 					}
 						
 					foreach(TreeIter iter in iters) {
-						if(playlistModel.IterIsValid(destIter))
+						if(!playlistModel.IterIsValid(destIter))
+							break;
+
+						if (pos == TreeViewDropPosition.After ||
+						    pos == TreeViewDropPosition.IntoOrAfter) {
 							playlistModel.MoveAfter(iter, destIter);
-						
-						destIter = iter.Copy();						
-					}	
+							destIter = iter.Copy();
+						} else
+							playlistModel.MoveBefore(iter, destIter);
+					}
 									
 					break;
 			}
@@ -1647,7 +1690,7 @@ namespace Banshee
 				} catch(Exception e) {
 					HigMessageDialog.RunHigMessageDialog(null, 
 						DialogFlags.Modal, MessageType.Error, ButtonsType.Ok, 
-						"Could Not Eject",
+						Catalog.GetString("Could Not Eject"),
 						e.Message);
 				}
 			}
@@ -1684,7 +1727,7 @@ namespace Banshee
 			activeTrackInfo = null;
 			
 			if(trayIcon != null)
-				trayIcon.Tooltip = "Banshee - Idle";
+				trayIcon.Tooltip = Catalog.GetString("Banshee - Idle");
 		}
 	}
 }
