@@ -157,7 +157,8 @@ namespace Banshee
 			CursorChanged += OnCursorChanged;
 			
 			try {
-				IpodCore.Instance.Updated += OnIpodCoreUpdated;
+				Core.Instance.IpodCore.Updated += OnIpodCoreUpdated;
+				Core.Instance.AudioCdCore.Updated += OnAudioCdCoreUpdated;
 			} catch(NullReferenceException) {}
 			
 			RefreshList();
@@ -194,10 +195,15 @@ namespace Banshee
 			
 			// iPod Sources
 			try {
-				foreach(IPod.Device device in IpodCore.Instance.Devices)
+				foreach(IPod.Device device in Core.Instance.IpodCore.Devices)
 					store.AppendValues(new IpodSource(device));
 			} catch(NullReferenceException) {}
 			
+			try {
+				foreach(AudioDisk disk in Core.Instance.AudioCdCore.Disks)
+					store.AppendValues(new AudioCdSource(disk));
+			} catch(NullReferenceException) {}
+			
 			// Playlist Sources
 			string [] names = Playlist.ListAll();
 			
@@ -273,6 +279,11 @@ namespace Banshee
 			RefreshList();
 		}
 		
+		private void OnAudioCdCoreUpdated(object o, EventArgs args)
+		{
+			RefreshList();
+		}
+		
 		public Source GetSource(TreePath path)
 		{
 			TreeIter iter;
@@ -401,6 +412,9 @@ namespace Banshee
 				case SourceType.Ipod:
 					iconFile = "source-ipod-regular.png";
 					break;
+				case SourceType.AudioCd:
+					iconFile = "source-cd-audio.png";
+					break;
 				case SourceType.Library:
 				default:
 					iconFile = "source-library.png";
